==> haskell-distributive-0.6.2.1-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-1KldFc1dv1YJDeXwzsDNLT
key:                  distributive-0.6.2.1-1KldFc1dv1YJDeXwzsDNLT
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  6e9778e718fce1209326dbfb07e140af
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.0.1/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/distributive-0.6.2.1
hs-libraries:         HSdistributive-0.6.2.1-1KldFc1dv1YJDeXwzsDNLT
depends:
    base-4.15.0.0 base-orphans-0.8.4-JqDLfiw7Hp3KhAG0NCBcfD
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6.2.1-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-1bfWRE0H1TMI8Z4LQ3ewQ2
key:                  distributive-0.6.2.1-1bfWRE0H1TMI8Z4LQ3ewQ2
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  533241b15938db342f5df649d0db693b
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.0.1/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/distributive-0.6.2.1
hs-libraries:         HSdistributive-0.6.2.1-1bfWRE0H1TMI8Z4LQ3ewQ2
depends:
    base-4.15.0.0 base-orphans-0.8.4-LGOXqKBEgmx34lvmgu6ajm
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
